@@ -42,9 +42,7 @@ MULTIWHITESPACE = re.compile("[ \n\t]{2}(?!\\\\n)")
 ESCAPE_TRANSLATE = str.maketrans(
     {
         "\\": "\\\\",
-        # This will add non intrusive real newlines to
-        # ones in translation improving readability of result
-        "\n": "\n\\n",
+        "\n": "\\n",
         "\t": "\\t",
         "'": "\\'",
         '"': '\\"',
@@ -71,6 +69,8 @@ class DecodingXMLParser:
         self.decoded_emit = None
         self.character_data = False
         self.raw_string = True
+        self.in_string = False
+        self.do_cleanup = False
         self.depth = 0
         self.parser = parser = ParserCreate()
         if self.FOREGIN_DTD:
@@ -84,130 +84,21 @@ class DecodingXMLParser:
         parser.DefaultHandler = self.DefaultHandler
 
     @staticmethod
-    def process_string(text: str) -> str:
-        return AndroidResourceUnit.unescape(text, strip=False)
-
-    def emit(self):
-        if self.emit_start is not None:
-            text = self.text[self.emit_start : self.parser.CurrentByteIndex].decode(
-                "utf-8"
-            )
-            if not self.raw_string:
-                text = self.process_string(text)
-            self.output.append(text)
-            self.emit_start = None
-        self.character_data = False
-        self.raw_string = True
-
-    def StartElementHandler(self, _name, _attributes):
-        self.emit()
-        if self.depth >= self.EMIT_DEPTH:
-            self.emit_start = self.parser.CurrentByteIndex
-        self.depth += 1
-
-    def EndElementHandler(self, _name):
-        self.emit()
-        if self.depth >= self.EMIT_DEPTH:
-            self.emit_start = self.parser.CurrentByteIndex
-        self.depth -= 1
-
-    def CharacterDataHandler(self, _data):
-        if not self.character_data:
-            self.emit()
-            self.emit_start = self.parser.CurrentByteIndex
-            self.raw_string = False
-
-    def StartCdataSectionHandler(self):
-        self.emit()
-        self.character_data = True
-        self.emit_start = self.parser.CurrentByteIndex
-
-    def EndCdataSectionHandler(self):
-        self.character_data = False
-
-    def DefaultHandler(self, _data):
-        if self.depth >= self.EMIT_DEPTH:
-            self.emit()
-            self.emit_start = self.parser.CurrentByteIndex
-
-    def parse(self) -> str:
-        self.parser.Parse(self.text, True)
-        if self.depth >= self.EMIT_DEPTH:
-            self.emit()
-        return "".join(self.output)
-
-
-class EncodingXMLParser(DecodingXMLParser):
-    EMIT_DEPTH = 0
-    FOREGIN_DTD = False
-
-    @staticmethod
-    def process_string(text: str) -> str:
-        return AndroidResourceUnit.escape(text, quote_wrapping_whitespaces=False)
-
-    def parse(self) -> str:
-        self.emit_start = 0
-        return super().parse()
-
-
-class AndroidResourceUnit(base.TranslationUnit):
-    """A single entry in the Android String resource file."""
-
-    SINGULAR_TAG = "string"
-    PLURAL_TAG = "plurals"
-
-    @classmethod
-    def createfromxmlElement(cls, element):
-        term = None
-        # Actually this class supports only plurals and string tags
-        if element.tag in (cls.PLURAL_TAG, cls.SINGULAR_TAG):
-            term = cls(None, xmlelement=element)
-        return term
-
-    def __init__(self, source, empty=False, xmlelement=None, **kwargs):
-        if xmlelement is not None:
-            self.xmlelement = xmlelement
-        elif self.hasplurals(source):
-            self.xmlelement = etree.Element(self.PLURAL_TAG)
-        else:
-            self.xmlelement = etree.Element(self.SINGULAR_TAG)
-        if source is not None:
-            self.setid(source)
-        super().__init__(source)
-
-    def istranslatable(self):
-        return bool(self.getid()) and self.xmlelement.get("translatable") != "false"
-
-    def isblank(self):
-        return not bool(self.getid())
-
-    def getid(self):
-        return self.xmlelement.get("name")
-
-    def setid(self, newid):
-        return self.xmlelement.set("name", newid)
-
-    def getcontext(self):
-        return self.xmlelement.get("name")
-
-    @staticmethod
-    def unescape(text, strip=True):
+    def process_string(text: str) -> tuple[str, bool, bool]:
         """
         Remove escaping from Android resource.
 
         Code is based on android2po
         <https://github.com/miracle2k/android2po>
         """
-        # Return text for empty elements
-        if text is None:
-            return ""
-
         # Mirror globals into locals for faster lookups
         eof = EOF
         whitespace = WHITESPACE
         escape_newline = ESCAPE_NEWLINE
         escape_tab = ESCAPE_TAB
         escape_plain = ESCAPE_PLAIN
+        cleanup_start = True
+        cleanup_end = True
 
         # We need to collapse multiple whitespace while paying
         # attention to Android's quoting and escaping.
@@ -235,20 +126,26 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # non-significant newlines/tabs etc.
                         text[i - space_count : i] = " "
                         i -= space_count - 1
-                        if strip and (i == 1 or c is eof):
-                            del text[i - 1]
                     space_count = 0
                 else:
                     space_count = 0
 
             # Handle quotes
             if c == '"' and not active_escape:
+                if i == 0:
+                    cleanup_start = False
+                if active_quote:
+                    cleanup_end = False
                 active_quote = not active_quote
                 del text[i]
                 i -= 1
+            elif c is not eof:
+                cleanup_end = True
 
             # Handle escapes
             if c == "\\":
+                if i == 0:
+                    cleanup_start = False
                 if not active_escape:
                     active_escape = True
                 else:
@@ -261,17 +158,15 @@ class AndroidResourceUnit(base.TranslationUnit):
                 # Handle the limited amount of escape codes
                 # that we support.
                 # TODO: What about \r, or \r\n?
+                cleanup_end = False
                 if c is eof:
                     # Basically like any other char, but put
                     # this first so we can use the ``in`` operator
                     # in the clauses below without issue.
                     pass
                 elif c in escape_newline:
-                    # Remove whitespace just before newline. Most likely this is result of
-                    # having real newline in the XML in front of \n.
-                    offset = 2 if i >= 2 and text[i - 2] == " " else 1
-                    text[i - offset : i + 1] = "\n"  # an actual newline
-                    i -= offset
+                    text[i - 1 : i + 1] = "\n"  # an actual newline
+                    i -= 1
                 elif c in escape_tab:
                     text[i - 1 : i + 1] = "\t"  # an actual tab
                     i -= 1
@@ -293,14 +188,18 @@ class AndroidResourceUnit(base.TranslationUnit):
                     codepoint_str = "".join(text[i + 1 : max_slice])
                     if len(codepoint_str) < 4:
                         codepoint_str = "0" * (4 - len(codepoint_str)) + codepoint_str
+                    # We can't trust int() to raise a ValueError,
+                    # it will ignore leading/trailing whitespace.
+                    if not codepoint_str.isalnum():
+                        raise ValueError(
+                            f"Invalid unicode escape sequence: {codepoint_str!r}"
+                        )
                     try:
-                        # We can't trust int() to raise a ValueError,
-                        # it will ignore leading/trailing whitespace.
-                        if not codepoint_str.isalnum():
-                            raise ValueError(codepoint_str)
                         codepoint = chr(int(codepoint_str, 16))
                     except ValueError:
-                        raise ValueError("bad unicode escape sequence")
+                        raise ValueError(
+                            f"Invalid unicode escape sequence: {codepoint_str!r}"
+                        )
 
                     text[i - 1 : max_slice] = codepoint
                     i -= 1
@@ -313,7 +212,131 @@ class AndroidResourceUnit(base.TranslationUnit):
             i += 1
 
         # Join the string together again, but w/o EOF marker
-        return "".join(text[:-1])
+        return "".join(text[:-1]), cleanup_start, cleanup_end
+
+    def cleanup_text(self, text: str) -> str:
+        """Remove leading whitespace from text."""
+        if not self.output:
+            return text.lstrip()
+        return text
+
+    def emit(self):
+        if self.emit_start is not None:
+            text = self.text[self.emit_start : self.parser.CurrentByteIndex].decode(
+                "utf-8"
+            )
+            self.do_cleanup = not self.raw_string
+            if not self.raw_string:
+                text, cleanup_start, self.do_cleanup = self.process_string(text)
+                if cleanup_start:
+                    text = self.cleanup_text(text)
+            self.output.append(text)
+            self.emit_start = None
+        self.character_data = False
+        self.raw_string = True
+        self.in_string = False
+
+    def StartElementHandler(self, _name, _attributes):
+        self.emit()
+        if self.depth >= self.EMIT_DEPTH:
+            self.emit_start = self.parser.CurrentByteIndex
+        self.depth += 1
+
+    def EndElementHandler(self, _name):
+        self.emit()
+        if self.depth >= self.EMIT_DEPTH:
+            self.emit_start = self.parser.CurrentByteIndex
+        self.depth -= 1
+
+    def CharacterDataHandler(self, _data):
+        if not self.character_data and not self.in_string:
+            self.emit()
+            self.emit_start = self.parser.CurrentByteIndex
+            self.raw_string = False
+            self.in_string = True
+
+    def StartCdataSectionHandler(self):
+        self.emit()
+        self.character_data = True
+        self.emit_start = self.parser.CurrentByteIndex
+
+    def EndCdataSectionHandler(self):
+        self.character_data = False
+
+    def DefaultHandler(self, _data):
+        if self.depth >= self.EMIT_DEPTH:
+            self.emit()
+            self.emit_start = self.parser.CurrentByteIndex
+
+    def parse(self) -> str:
+        self.parser.Parse(self.text, True)
+        if self.depth >= self.EMIT_DEPTH:
+            self.emit()
+        # Remove trailing whitespace from text
+        if self.do_cleanup and self.output:
+            self.output[-1] = self.output[-1].rstrip()
+        return "".join(self.output)
+
+
+class EncodingXMLParser(DecodingXMLParser):
+    EMIT_DEPTH = 0
+    FOREGIN_DTD = False
+
+    @staticmethod
+    def process_string(text: str) -> tuple[str, bool, bool]:
+        return (
+            AndroidResourceUnit.escape(text, quote_wrapping_whitespaces=False),
+            False,
+            False,
+        )
+
+    def parse(self) -> str:
+        self.emit_start = 0
+        return super().parse()
+
+
+class AndroidResourceUnit(base.TranslationUnit):
+    """A single entry in the Android String resource file."""
+
+    SINGULAR_TAG = "string"
+    PLURAL_TAG = "plurals"
+
+    @classmethod
+    def createfromxmlElement(cls, element):
+        term = None
+        # Actually this class supports only plurals and string tags
+        if element.tag in {cls.PLURAL_TAG, cls.SINGULAR_TAG}:
+            term = cls(None, xmlelement=element)
+        return term
+
+    def __init__(self, source, empty=False, xmlelement=None, **kwargs):
+        if xmlelement is not None:
+            self.xmlelement = xmlelement
+        elif self.hasplurals(source):
+            self.xmlelement = etree.Element(self.PLURAL_TAG)
+        else:
+            self.xmlelement = etree.Element(self.SINGULAR_TAG)
+        if source is not None:
+            self.setid(source)
+        super().__init__(source)
+
+    def istranslatable(self):
+        return bool(self.getid()) and self.xmlelement.get("translatable") != "false"
+
+    def marktranslatable(self, value: bool) -> None:
+        return self.xmlelement.set("translatable", "true" if value else "false")
+
+    def isblank(self):
+        return not bool(self.getid())
+
+    def getid(self):
+        return self.xmlelement.get("name")
+
+    def setid(self, newid):
+        return self.xmlelement.set("name", newid)
+
+    def getcontext(self):
+        return self.xmlelement.get("name")
 
     @staticmethod
     def xml_escape_space(matchobj):
@@ -364,11 +387,23 @@ class AndroidResourceUnit(base.TranslationUnit):
         return super().source
 
     def get_xml_text_value(self, xmltarget):
-        if len(xmltarget) == 0:
-            # There are no html markups, so unescaping it as plain text.
-            return self.unescape(xmltarget.text)
+        raw_xml = etree.tostring(xmltarget, encoding="unicode", with_tail=False)
+        # Unescape as plain text in case there is no XML markup. Ufortunately
+        # CDATA elements are not listed as childs in lxml, so test for it in raw XML.
+        if len(xmltarget) == 0 and "<![CDATA[" not in raw_xml:
+            if xmltarget.text is None:
+                return ""
+            text, cleanup_start, cleanup_end = DecodingXMLParser.process_string(
+                xmltarget.text
+            )
+            if cleanup_start:
+                text = text.lstrip()
+            if cleanup_end:
+                text = text.rstrip()
+            return text
 
-        parser = DecodingXMLParser(etree.tostring(xmltarget, encoding="unicode"))
+        # Use decoding parser to keep XML entitities, CDATA while processing Android escaping
+        parser = DecodingXMLParser(raw_xml)
         return parser.parse()
 
     def set_xml_text_plain(self, target, xmltarget):
@@ -396,7 +431,8 @@ class AndroidResourceUnit(base.TranslationUnit):
             else:
                 template = "<resources></resources>"
             newstring = template.replace(
-                "</resources>", f"<string>{target}</string></resources>"
+                "</resources>",
+                f"<{xmltarget.tag}>{target}</{xmltarget.tag}></resources>",
             )
             try:
                 etree.fromstring(newstring, parser)
@@ -407,15 +443,17 @@ class AndroidResourceUnit(base.TranslationUnit):
                 encoding_parser = EncodingXMLParser(newstring)
                 newstring = encoding_parser.parse()
                 newtree = etree.fromstring(newstring, parser)[0]
+                # Copy existing attributes
+                for attribute, value in xmltarget.items():
+                    newtree.attrib[attribute] = value
                 # Update text
-                xmltarget.text = newtree.text
-
-                # Remove old elements
-                for x in xmltarget.iterchildren():
-                    xmltarget.remove(x)
-                # Add new elements
-                for x in newtree.iterchildren():
-                    xmltarget.append(x)
+                parent = xmltarget.getparent()
+                # Parent can be none when operating on Unit only without a storage
+                if parent is not None:
+                    parent.replace(xmltarget, newtree)
+                # Update unit xmlelement if needed (plurals are inner elements here)
+                if xmltarget == self.xmlelement:
+                    self.xmlelement = newtree
         else:
             self.set_xml_text_plain(target, xmltarget)
 
@@ -429,8 +467,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         if not locale:
             return data.plural_tags["en"]
         # Handle b+ style language codes
-        if locale.startswith("b+"):
-            locale = locale[2:]
+        locale = locale.removeprefix("b+")
         locale = locale.replace("_", "-").replace("+", "-").split("-")[0]
         return data.plural_tags.get(locale, data.plural_tags["en"])
 
@@ -475,8 +512,8 @@ class AndroidResourceUnit(base.TranslationUnit):
             for plural_tag, plural_string in zip(plural_tags, plural_strings):
                 item = etree.Element("item")
                 item.set("quantity", plural_tag)
-                self.set_xml_text_value(plural_string, item)
                 self.xmlelement.append(item)
+                self.set_xml_text_value(plural_string, item)
         else:
             # Fix the root tag if mismatching
             if self.xmlelement.tag != self.SINGULAR_TAG:
@@ -494,13 +531,13 @@ class AndroidResourceUnit(base.TranslationUnit):
 
     # Notes are handled as previous sibling comments.
     def addnote(self, text, origin=None, position="append"):
-        if origin in ["programmer", "developer", "source code", None]:
+        if origin in {"programmer", "developer", "source code", None}:
             self.xmlelement.addprevious(etree.Comment(text))
         else:
             super().addnote(text, origin=origin, position=position)
 
     def getnotes(self, origin=None):
-        if origin in ["programmer", "developer", "source code", None]:
+        if origin in {"programmer", "developer", "source code", None}:
             comments = []
             if self.xmlelement is not None:
                 prevSibling = self.xmlelement.getprevious()
