@@ -368,7 +368,7 @@ class pounit(pocommon.pounit):
         encoding = encoding or "utf-8"
         if not gpo_message:
             self._gpo_message = gpo.po_message_create()
-        if source or source == "":
+        if isinstance(source, str):
             self.source = source
             self.target = ""
         elif gpo_message:
@@ -439,7 +439,7 @@ class pounit(pocommon.pounit):
                 pluralform = (
                     gpo_decode(gpo.po_message_msgid_plural(self._gpo_message)) or ""
                 )
-                multi.strings.append(pluralform)
+                multi.extra_strings.append(pluralform)
                 return multi
             return singular
         return ""
@@ -545,7 +545,7 @@ class pounit(pocommon.pounit):
             ) + gpo.po_message_extracted_comments(self._gpo_message)
         elif origin == "translator":
             comments = gpo.po_message_comments(self._gpo_message)
-        elif origin in ["programmer", "developer", "source code"]:
+        elif origin in {"programmer", "developer", "source code"}:
             comments = gpo.po_message_extracted_comments(self._gpo_message)
         else:
             raise ValueError("Comment type not valid")
@@ -587,7 +587,7 @@ class pounit(pocommon.pounit):
                 else:
                     newlines.append(line)
             newnotes = gpo_encode("\n".join(newlines))
-            if origin in ["programmer", "developer", "source code"]:
+            if origin in {"programmer", "developer", "source code"}:
                 gpo.po_message_set_extracted_comments(self._gpo_message, newnotes)
             else:
                 gpo.po_message_set_comments(self._gpo_message, newnotes)
@@ -646,7 +646,7 @@ class pounit(pocommon.pounit):
     def isheader(self):
         # return self.source == "" and self.target != ""
         # we really want to make sure that there is no msgidcomment or msgctxt
-        return self.getid() == "" and len(self.target) > 0
+        return not self.getid() and len(self.target) > 0
 
     def isblank(self):
         return len(self.source) == len(self.target) == len(self.getcontext()) == 0
