@@ -676,7 +676,7 @@ class pounit(pocommon.pounit):
     def markfuzzy(self, present=True):
         if present:
             self.set_state_n(self.STATE[self.S_FUZZY][0])
-        elif self.hasplural() and not self._msgstrlen() or is_null(self.msgstr):
+        elif (self.hasplural() and not self._msgstrlen()) or is_null(self.msgstr):
             self.set_state_n(self.STATE[self.S_UNTRANSLATED][0])
         else:
             self.set_state_n(self.STATE[self.S_TRANSLATED][0])
@@ -739,8 +739,7 @@ class pounit(pocommon.pounit):
                 combinedcomment = []
                 for comment in partcomments:
                     comment = unquotefrompo([comment])
-                    if comment.startswith("_:"):
-                        comment = comment[len("_:") :]
+                    comment = comment.removeprefix("_:")
                     if comment.endswith("\\n"):
                         comment = comment[: -len("\\n")]
                     # Before we used to strip. Necessary in some cases?
