@@ -430,9 +430,7 @@ class xliffunit(lisa.LISAunit):
 
     def istranslatable(self):
         value = self.xmlelement.get("translate")
-        if value and value.lower() == "no":
-            return False
-        return True
+        return not value or value.lower() != "no"
 
     def marktranslated(self):
         state_id = self.get_state_id()
@@ -694,7 +692,7 @@ class xlifffile(lisa.LISAfile):
         filenodes = self.document.getroot().iterchildren(self.namespaced("file"))
         filenames = [self.getfilename(filenode) for filenode in filenodes]
         filenames = list(filter(None, filenames))
-        if len(filenames) == 1 and filenames[0] == "":
+        if len(filenames) == 1 and not filenames[0]:
             filenames = []
         return filenames
 
